==> am_mod_grp_0_3.zip: am_mod_grp_0_3/components/grp/language/1/barnraiser_01/edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/grp_common.inc.php');


// HEADERS
$lang['hdr_policy'] = 								"edit group policy";
$lang['hdr_group_edit'] = 							"edit group";
$lang['hdr_topic'] = 								"topic";


// SUBMIT BUTTONS
$lang['sub_preview'] =                        	  	"preview";
$lang['sub_insert'] =                            	"add your group";
$lang['sub_update'] =                            	"update your group";
$lang['sub_policy'] = 								"update policy";


// ERROR MESSAGES
$lang['error']['title_empty'] = 					"You have not given a title to your group.";
$lang['error']['synopsis_empty'] = 					"You have not given a synopsis to your group.";
$lang['error']['unixname_incorrect'] = 				"Your group unix name can only contain characters (A-Z or a-z) and numbers (0-9).";
$lang['error']['unixname_inuse'] = 					"Sorry, your group unix name is aleady in use. Please create another.";
$lang['error']['policy_empty'] = 					"Your group policy is empty.";



//BODY TEXT
$lang['txt_title'] = 								"title";
$lang['txt_unix_title'] = 							"unix title";
$lang['txt_synopsis'] = 							"synopsis";
$lang['txt_location'] = 							"location";
$lang['txt_location_none'] = 						"not location based";
$lang['txt_publish'] = 								"publish";
$lang['txt_body'] = 								"details";
$lang['txt_status'] = 								"status";
$lang['txt_age'] = 									"age";
$lang['txt_lang'] = 								"language";
$lang['txt_participation'] = 						"participation";
$lang['txt_image'] = 								"picture";
$lang['txt_none'] = 								"none";
$lang['txt_policy'] = 								"policy";
$lang['txt_my_identity'] =								"my participation";

?>

==> am_mod_grp_0_4.zip: am_mod_grp_0_4/components/grp/language/1/barnraiser_01/edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/grp_common.inc.php');


// HEADERS
$lang['hdr_policy'] = 								"edit group policy";
$lang['hdr_group_edit'] = 							"edit group";
$lang['hdr_topic'] = 								"topic";


// SUBMIT BUTTONS
$lang['sub_preview'] =                        	  	"validate";
$lang['sub_insert'] =                            	"add your group";
$lang['sub_update'] =                            	"update your group";
$lang['sub_policy'] = 								"update policy";


// ERROR MESSAGES
$lang['error']['title_empty'] = 					"You have not given a title to your group.";
$lang['error']['synopsis_empty'] = 					"You have not given a synopsis to your group.";
$lang['error']['unixname_incorrect'] = 				"Your group unix name can only contain characters (A-Z or a-z) and numbers (0-9).";
$lang['error']['unixname_inuse'] = 					"Sorry, your group unix name is aleady in use. Please create another.";
$lang['error']['policy_empty'] = 					"Your group policy is empty.";



//BODY TEXT
$lang['txt_title'] = 								"title";
$lang['txt_unix_title'] = 							"unix title";
$lang['txt_synopsis'] = 							"synopsis";
$lang['txt_location'] = 							"location";
$lang['txt_location_none'] = 						"not location based";
$lang['txt_publish'] = 								"publish";
$lang['txt_body'] = 								"details";
$lang['txt_status'] = 								"status";
$lang['txt_age'] = 									"age";
$lang['txt_lang'] = 								"language";
$lang['txt_participation'] = 						"participation";
$lang['txt_image'] = 								"picture";
$lang['txt_none'] = 								"none";
$lang['txt_my_identity'] =							"my participation";

$lang['txt_file_to_upload'] = 						"file";
$lang['txt_file_to_upload_name'] = 					"filename";
$lang['txt_title_intro'] = 							"describe your group";
$lang['txt_title_create'] = 						"create your group home page";
$lang['txt_title_save'] = 							"check and save your group";
$lang['txt_title_image'] = 							"add a thumbnail image to your group";
$lang['txt_title_policy'] = 						"create your group policy";

?>
